@@ -19,7 +19,7 @@ use constant SPECIFICATION_URL => 'http://json-schema.org/draft-04/schema#';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.97';
+our $VERSION = '0.98';
 our @EXPORT_OK = 'validate_json';
 
 my $BUNDLED_CACHE_DIR = path(path(__FILE__)->dirname, qw(Validator cache));
@@ -452,6 +452,15 @@ sub _validate_type_enum {
     map { ref $_ ? Mojo::JSON::encode_json($_) : $_ } @$enum;
 }
 
+sub _validate_type_const {
+  my ($self, $data, $path, $schema) = @_;
+  my $const = $schema->{const};
+  my $m     = S $data;
+
+  return if $m eq S $const;
+  return E $path, sprintf 'Does not match const: %s.', Mojo::JSON::encode_json($const);
+}
+
 sub _validate_format {
   my ($self, $value, $path, $schema) = @_;
   my $code = $self->formats->{$schema->{format}};
@@ -636,6 +645,8 @@ sub _validate_type_object {
         push @errors, @e;
         push @errors, $self->_validate_type_enum($data->{$k}, _path($path, $k), $r)
           if $r->{enum} and !@e;
+        push @errors, $self->_validate_type_const($data->{$k}, _path($path, $k), $r)
+          if $r->{const} and !@e;
       }
     }
   }
@@ -730,7 +741,8 @@ sub _guess_schema_type {
     or defined $_[0]->{minLength};
   return _guessed_right($_[1], 'number') if $_[0]->{multipleOf};
   return _guessed_right($_[1], 'number') if defined $_[0]->{maximum} or defined $_[0]->{minimum};
-  return 'enum' if $_[0]->{enum};
+  return 'enum'  if $_[0]->{enum};
+  return 'const' if $_[0]->{const};
   return undef;
 }
 
@@ -828,7 +840,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.97
+0.98
 
 =head1 SYNOPSIS
 
@@ -1207,6 +1219,8 @@ Jan Henning Thorsen - C<jhthorsen@cpan.org>
 
 Daniel Böhmer - C<post@daniel-boehmer.de>
 
+Kevin Goess - C<cpan@goess.org>
+
 Martin Renvoize - C<martin.renvoize@gmail.com>
 
 =cut
